Map

Trait Map 

pub trait Map {
    type Key;
    type Value;
}
This trait is implemented by all the map wrapper types, as as convenient way to communicate their underlying types to the Rust type system.

Required Associated Types

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl Map for rebpf::bpf::maps::CpuMap

Source

impl Map for rebpf::userspace::maps::CpuMap

Source

impl Map for DevMap

Source

impl Map for XskMap

Source

impl<T> Map for rebpf::bpf::maps::Array<T>

Source

impl<T> Map for rebpf::userspace::maps::Array<T>

Source

impl<T> Map for rebpf::bpf::maps::PerCpuArray<T>

Source

impl<T> Map for rebpf::userspace::maps::PerCpuArray<T>