pub trait Map {
type Key;
type Value;
}Expand description
This trait is implemented by all the map wrapper types, as as convenient way to communicate their underlying types to the Rust type system.
Required Associated Types
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".